@@ -4,13 +4,14 @@ https://raw.github.com/malsup/form/master/jquery.form.js
 //{{{
 /*!
  * jQuery Form Plugin
- * version: 3.01 (06-MAR-2012)
+ * version: 3.03 (08-MAR-2012)
  * @requires jQuery v1.3.2 or later
  *
  * Examples and documentation at: http://malsup.com/jquery/form/
+ * Project repository: https://github.com/malsup/form
  * Dual licensed under the MIT and GPL licenses:
- *    http://www.opensource.org/licenses/mit-license.php
- *    http://www.gnu.org/licenses/gpl.html
+ *    http://malsup.github.com/mit-license.txt
+ *    http://malsup.github.com/gpl-license-v2.txt
  */
 /*global ActiveXObject alert */
 ;(function($) {
@@ -237,7 +238,9 @@ $.fn.ajaxSubmit = function(options) {
 				var xhr = jQuery.ajaxSettings.xhr();
 				if (xhr.upload) {
 					xhr.upload.onprogress = function(event) {
-						var percent = parseInt((event.position / event.total) * 100, 10);
+						var percent = 0;
+						if (event.lengthComputable)
+							percent = parseInt((event.position / event.total) * 100, 10);
 						options.uploadProgress(event, event.position, event.total, percent);
 					}
 				}
